function [ Kl,Cl,Ml ] = elmt24( local_data )
% elmt24: 2-D three-node (triangular) element for plane strain deformation with 2 dof per node 
% for 2nd order PDE in (x1,x2)
% (Constant strain triangle, etc.)
%
% Element subroutine to construct local stiffness matrix from local data
%
%  local_data.mater = [elt# Modulus Poisson ratio Density prop4 prop5 ] For material type
%
%  local_data.coords = [ x1 x2 of node 1;
%                        x1 x2 of node 2;
%                        x1 x2 of node 3]
%
%  local_data.dofs   = [ dof1 dof2 dof3] Global dof referenced to local dofs
%
  Kl = zeros(6,6);
  Cl = zeros(6,6);
  Ml = zeros(6,6);
  D  = zeros(3,3);
  A  = zeros(3,6);
%
%  Constitutive matrix - Darcy's Law, Fick's Law, Fourier's Law, Ohm's Law
%
  Emod    = local_data.mater(1,2);
  nu      = local_data.mater(1,3);
  density = local_data.mater(1,4);
%-------------------------------- Evalaute constitutive matrix
  D =  [ 1 2 0; 
         3 4 0; 
         0 0 5]
                              
%-------------------------------- Evaluate coefs and determinant for element area
  
%-------------------------------- Evaluate derivatives of shape functions
A = [ 21   0   22   0   23   0;
      0   31   0   32   0   33;
        31  21  32  22  33  23] 
%-------------------------------- Evalaute conductance matrix
thickness = 1;
Kl = [1 2 3 4 5 6; 
      2 7 8 9 1 2; 
      3 8 1 2 3 4;
      4 9 2 4 5 6; 
      5 1 3 5 6 7;
      6 2 4 6 7 1]


         
         
